@@ -25,6 +25,19 @@ class BundleItemV1(InitOptions):
         self.Item = BundleItemInfoV1.from_dict(**self.Item)
 
 
+@dataclass
+class BundleItemV2(InitOptions):
+    uuid: str
+    name: str
+    image: str
+    type: str
+    amount: int
+    discount_percent: float
+    base_price: int
+    discounted_price: int
+    promo_item: bool
+
+
 @dataclass
 class BundleV1(InitOptions):
     ID: str
@@ -38,6 +51,16 @@ class BundleV1(InitOptions):
         self.Items = [BundleItemV1.from_dict(**item) for item in self.Items]
 
 
+@dataclass
+class BundleV2(InitOptions):
+    bundle_uuid: str
+    items: List[BundleItemV2]
+    seconds_remaining: int
+
+    def __post_init__(self):
+        self.items = [BundleItemV2.from_dict(**item) for item in self.items]
+
+
 @dataclass
 class FeaturedBundleV1(InitOptions):
     Bundle: BundleV1
